/////////////////////////////////////////////////////////////////////////
// MIT License
//
// Copyright (c) 2000-2011 OpenNETCF Consulting, LLC
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
// documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
// and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE 
// WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
// COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  
////////////////////////////////////////////////////////////////////////

using System;
using System.Collections;

namespace OpenNETCF.Windows.Forms.Calendar
{
	/// <summary>
	/// Summary description for CalendarItemComparer.
	/// </summary>
	public class CalendarItemComparer: IComparer
	{
		#region IComparer Members

        /// <summary>
        /// Compares two calendar items and returns an indication of thier relative values
        /// </summary>
        /// <param name="x"></param>
        /// <param name="y"></param>
        /// <returns></returns>
		public int Compare(object x, object y)
		{
			CalendarItem item1 = x as CalendarItem;
			CalendarItem item2 = y as CalendarItem;
			if( item1 == null || item2 == null )
				return 0;
			if ( item1.StartTime == item2.StartTime )
				return item1.Duration.CompareTo(item2.Duration);
			else
				return item1.StartTime.CompareTo(item2.StartTime);
		}

		#endregion
	}
}
