/////////////////////////////////////////////////////////////////////////
// MIT License
//
// Copyright (c) 2000-2011 OpenNETCF Consulting, LLC
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
// documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
// and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE 
// WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
// COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  
////////////////////////////////////////////////////////////////////////

using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;

namespace OpenNETCF.Windows.Forms
{
	#region MeasureItemEventArgs class

    /// <summary>
    /// Provides data for the MeasureItem event.
    /// </summary>
	public class MeasureItemEventArgs : EventArgs
	{
		private Graphics graphics;
		private int index;
		private int itemHeight;
		private int itemWidth = 0;

        /// <summary>
        /// Contructor
        /// </summary>
        /// <param name="graphics">graphics object used to measure</param>
        /// <param name="index">current index</param>
		public MeasureItemEventArgs(Graphics graphics, int index)
		{
			this.graphics = graphics;
			this.index = index;
		}

        /// <summary>
        /// Overloaded contructor
        /// </summary>
        /// <param name="graphics">graphics object used to measure</param>
        /// <param name="index">current index</param>
        /// <param name="itemHeight">height of the item</param>
		public MeasureItemEventArgs(Graphics graphics, int index, int itemHeight)
			: this(graphics, index)
		{
			this.itemHeight = itemHeight;

		}

        /// <summary>
        /// Gets the graphics object associated with the event arguments
        /// </summary>
		public Graphics Graphics
		{
			get { return graphics; }
		}


        /// <summary>
        /// Gets the current index 
        /// </summary>
		public int Index
		{
			get { return index; }
			set { index = value; }
		}

        /// <summary>
        /// Gets the item height
        /// </summary>
		public int ItemHeight
		{
			get { return itemHeight; }
			set { itemHeight = value; }
		}

        /// <summary>
        /// Gets the item width
        /// </summary>
		public int ItemWidth
		{
			get { return itemWidth; }
			set { itemWidth = value; }
		}

	}


	#endregion

}
